==> twyt_0.9.0.orig.tar.gz: twyt-0.9.0/twyt/twyt.py <==
# Copyright (c) 2007-2009 Andrew Price
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. The name of the author may not be used to endorse or promote products
#    derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""
A Twitter client for the easily distracted
Author: Andrew Price <andy@andrewprice.me.uk>
"""

import sys
import commands
from twitter import TwitterException

def main():

	"""Run twyt"""

	cmds = commands.Commands()
	cmds.register_command(commands.TweetCommand())
	cmds.register_command(commands.DirectCommand())
	cmds.register_command(commands.DirectTLCommand())
	cmds.register_command(commands.DirectSentCommand())
	cmds.register_command(commands.DirectDelCommand())
	cmds.register_command(commands.PublicTLCommand())
	cmds.register_command(commands.FriendsTLCommand())
	cmds.register_command(commands.UserTLCommand())
	cmds.register_command(commands.ShowCommand())
	cmds.register_command(commands.RepliesCommand())
	cmds.register_command(commands.DeleteCommand())
	cmds.register_command(commands.BlockCommand())
	cmds.register_command(commands.UnblockCommand())
	cmds.register_command(commands.UserCommand())

	try:
		cmds.process_argv(sys.argv)
	except TwitterException, e:
		print >>sys.stderr, e
		sys.exit(1)


if __name__ == '__main__':
	main()

==> twyt_0.9.2.orig.tar.gz: twyt-0.9.2/twyt/twyt.py <==
# Copyright (c) 2007-2009 Andrew Price
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. The name of the author may not be used to endorse or promote products
#    derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""
A Twitter client for the easily distracted
Author: Andrew Price <andy@andrewprice.me.uk>
"""

import sys
import commands
from twitter import TwitterException

def main():

	"""Run twyt"""

	cmds = commands.Commands()
	cmds.register_command(commands.TweetCommand())
	cmds.register_command(commands.DirectCommand())
	cmds.register_command(commands.DirectTLCommand())
	cmds.register_command(commands.DirectSentCommand())
	cmds.register_command(commands.DirectDelCommand())
	cmds.register_command(commands.PublicTLCommand())
	cmds.register_command(commands.FriendsTLCommand())
	cmds.register_command(commands.UserTLCommand())
	cmds.register_command(commands.ShowCommand())
	cmds.register_command(commands.RepliesCommand())
	cmds.register_command(commands.DeleteCommand())
	cmds.register_command(commands.BlockCommand())
	cmds.register_command(commands.UnblockCommand())
	cmds.register_command(commands.UserCommand())
	cmds.register_command(commands.NameCacheCommand())
	cmds.register_command(commands.SingCommand())
	cmds.register_command(commands.IPLimitCommand())
	cmds.register_command(commands.AccountLimitCommand())

	try:
		cmds.process_argv(sys.argv)
	except TwitterException, e:
		print >>sys.stderr, e
		sys.exit(1)


if __name__ == '__main__':
	main()
